@@ -757,7 +757,7 @@ def fit_pulsed_frac(en, den, pf, dpf, stem=None, degree_pol=4, n_gauss=0, center
 
     #initialfit = mod.eval(pars, x=en)
 
-    out = mod.fit(pf, pars, x=en)
+    out = mod.fit(pf, pars, x=en, weights = 1./dpf)
 
     bb = (pf - out.best_fit) / dpf
 
